@@ -35,17 +35,12 @@ DAYS_OF_WEEK = (
 )
 
 
-def get_date(text, template='%Y%m%d'):
-    """ Get date from timestamp """
-    # TODO: del get_date
-    return time.strftime(template, time.localtime(text))
-
 def get_time(data=time.time(), template='%d.%m.%Y %H:%M:%S', tz=0):
     """ Get time from timestamp """
     # TODO: smart TZ
     return time.strftime(template, time.gmtime(data + tz * 3600))
 
-def parse_time(data, tz=0):
+def parse_time(data: str, tz=0):
     """ Parse time """
 
     data = data.lower()
@@ -57,6 +52,9 @@ def parse_time(data, tz=0):
     for day in DAYS_OF_WEEK:
         data = data.replace(day, '')
 
+    if len(data) < 13:
+        return None
+
     # Parse day
     if not data[1].isdigit():
         data = '0' + data
@@ -86,7 +84,11 @@ def parse_time(data, tz=0):
         tz_delta = tz
         # tz = pytz.utc
 
-    data = datetime.datetime.strptime(data, '%d.%m.%Y %H:%M:%S')
+    try:
+        data = datetime.datetime.strptime(data, '%d.%m.%Y %H:%M:%S')
+    except ValueError:
+        return None
+
     data = data.replace(
         tzinfo=datetime.timezone(datetime.timedelta(hours=tz_delta))
     )
